@@ -3,16 +3,11 @@ Class that wraps the credentials of the authenticated user. Think of
 this as a container that holds authentication related data.
 """
 
-# ************* Module stack **************
-# Your code has been rated at 10.00/10
-
 import enum
 import logging
 from urllib import parse
+from urllib3.util import Retry
 
-from urllib3 import Retry
-
-import contentstack
 from contentstack.asset import Asset
 from contentstack.assetquery import AssetQuery
 from contentstack.contenttype import ContentType
@@ -21,9 +16,10 @@ from contentstack.image_transform import ImageTransform
 
 __author__ = "ishaileshmishra (ishaileshmishra@gmail.com)"
 __license__ = "MIT"
-__version__ = '1.6.0'
+__version__ = '1.7.0'
 
 log = logging.getLogger(__name__)
+DEFAULT_HOST = 'cdn.contentstack.io'
 
 
 class ContentstackRegion(enum.Enum):
@@ -32,10 +28,10 @@ class ContentstackRegion(enum.Enum):
     """
     US = 'us'
     EU = 'eu'
+    AZURE_NA = 'azure-na'
 
 
 class Stack:
-    from urllib3.util import Retry
     """
     A stack can be defined as a pool of data or a container that holds all
     the content/assets related to a site. It is a collaboration space where multiple users can work
@@ -44,11 +40,12 @@ class Stack:
     """
 
     def __init__(self, api_key: str, delivery_token: str, environment: str,
-                 host='cdn.contentstack.io',
+                 host=DEFAULT_HOST,
                  version='v3',
                  region=ContentstackRegion.US,
                  timeout=30,
-                 retry_strategy=Retry(total=5, backoff_factor=0, status_forcelist=[408, 429]),
+                 retry_strategy=Retry(
+                     total=5, backoff_factor=0, status_forcelist=[408, 429]),
                  live_preview=None,
                  branch=None,
                  ):
@@ -56,14 +53,15 @@ class Stack:
         Class that wraps the credentials of the authenticated user. Think of
         this as a container that holds authentication related data.
 
-        :param api_key: api_key of the stack
+        param api_key: api_key of the stack
         :param delivery_token: delivery_token of the stack
         :param environment: environment of the stack
         :param host: (optional) host of the stack default is cdm.contentstack.io
         :param branch: branch of the stack
         :param version: (optional) apiVersion of the stack default is v3
         :param region: (optional) region support of the stack default is ContentstackRegion.US
-        :param live_preview: (optional) accepts type dictionary that enables live_preview option for request,
+        :param live_preview: (optional) accepts type dictionary that enables
+        live_preview option for request,
         takes input as dictionary object. containing one/multiple key value pair like below.
 
         ```python
@@ -75,13 +73,14 @@ class Stack:
             'edit_tags_type': object | str,
         }
         ```
-        :param retry_strategy (optional) custom retry_strategy can be set.
-        # Method to create retry_strategy: create object of Retry() and provide the
-        # required parameters like below
+        :param retry_strategy: (optional) custom retry_strategy can be set.
+        Method to create retry_strategy: create object of Retry() and provide the
+        required parameters like below
         **Example:**
+
         >>> _strategy = Retry(total=5, backoff_factor=1, status_forcelist=[408, 429])
         >>> stack = contentstack.Stack("api_key", "delivery_token", "environment",
-            live_preview={enable=True, authorization='your auth token'}, retry_strategy= _strategy)
+        live_preview={enable=True, authorization='your auth token'}, retry_strategy= _strategy)
         ```
         """
         if live_preview is None:
@@ -103,7 +102,6 @@ class Stack:
         self.retry_strategy = retry_strategy
         self.live_preview_dict = live_preview
 
-        # validate stack
         self._validate_stack()
 
     def _validate_stack(self):
@@ -116,11 +114,15 @@ class Stack:
         if self.environment is None or self.environment == "":
             raise PermissionError(
                 'You are not permitted to the stack without valid Environment')
-        # prepare endpoint for the url:
-        if self.region.value != 'us' and self.host == 'cdn.contentstack.io':
+
+        if self.region.value == 'eu' and self.host == DEFAULT_HOST:
             self.host = 'eu-cdn.contentstack.com'
-        self.endpoint = 'https://{}/{}'.format(self.host, self.version)
-        # prepare Headers:`
+        elif self.region.value == 'azure-na' and self.host == DEFAULT_HOST:
+            self.host = 'azure-na-cdn.contentstack.com'
+        elif self.region.value != 'us':
+            self.host = f'{self.region.value}-{DEFAULT_HOST}'
+        self.endpoint = f'https://{self.host}/{self.version}'
+
         self.headers = {
             'api_key': self.api_key,
             'access_token': self.delivery_token,
@@ -147,9 +149,8 @@ class Stack:
                 if 'host' not in self.live_preview_dict:
                     raise PermissionError("host is required")
                 self.headers['authorization'] = self.live_preview_dict['authorization']
-                # remove deliveryToken and environment
                 self.host = self.live_preview_dict['host']
-                self.endpoint = 'https://{}/{}'.format(self.host, self.version)
+                self.endpoint = f'https://{self.host}/{self.version}'
                 self.headers.pop('access_token')
                 self.headers.pop('environment')
 
@@ -238,18 +239,22 @@ class Stack:
         """
         return AssetQuery(self.http_instance)
 
-    def sync_init(self, content_type_uid=None, start_from=None, locale=None, type=None):
+    def sync_init(self, content_type_uid=None, start_from=None, locale=None, publish_type=None):
         """
-        Set init to ‘true’ if you want to sync all the published entries and assets. This is usually used when the
-        app does not have any content and you want to get all the content for the first time.\n
+        Set init to ‘true’ if you want to sync all the published entries and assets.
+        This is usually used when the app does not have any content and you want to
+        get all the content for the first time.\n
 
         :param content_type_uid: (optional) content type UID. e.g., products
                     This retrieves published entries of specified content type
         :param start_from: (optional) The start date. e.g., 2018-08-14T00:00:00.000Z
                     This retrieves published entries starting from a specific date
-        :param locale: (optional) locale code. e.g., en-us, This retrieves published entries of specific locale.
-        :param type: (optional) If you do not specify any value, it will bring all published 
-                    entries and published assets. You can pass multiple types as comma-separated values,
+        :param locale: (optional) locale code. e.g., en-us, This retrieves published
+        entries of specific locale.
+        :param publish_type: (optional) If you do not specify any value,
+                    it will bring all published
+                    entries and published assets. You can pass multiple types
+                    as comma-separated values,
                     for example, entry_published,entry_unpublished,asset_published
         :return: list of sync items
         -------------------------------
@@ -259,7 +264,7 @@ class Stack:
             >>> import contentstack
             >>> stack = contentstack.Stack('api_key', 'delivery_token', 'environment')
             >>> result = stack.sync_init(content_type_uid='content_type_uid',
-                         start_from='date', locale='en-us', type='asset_published')
+                         start_from='date', locale='en-us', publish_type='asset_published')
         -------------------------------
         """
         self.sync_param['init'] = 'true'
@@ -269,8 +274,8 @@ class Stack:
             self.sync_param['start_from'] = start_from
         if locale is not None and isinstance(locale, str):
             self.sync_param['locale'] = locale
-        if type is not None and isinstance(type, str):
-            self.sync_param['type'] = type
+        if publish_type is not None and isinstance(publish_type, str):
+            self.sync_param['type'] = publish_type
         return self.__sync_request()
 
     def pagination(self, pagination_token: str):
@@ -319,10 +324,10 @@ class Stack:
         :return: :class:`Response <Response>` object
         :rtype: requests.Response
         """
-        base_url = '{}/stacks/sync'.format(self.http_instance.endpoint)
+        base_url = f'{self.http_instance.endpoint}/stacks/sync'
         self.sync_param['environment'] = self.http_instance.headers['environment']
         encoded_query = parse.urlencode(self.sync_param)
-        url = '{}?{}'.format(base_url, encoded_query)
+        url = f'{base_url}?{encoded_query}'
         result = self.http_instance.get(url)
         return result
 
@@ -330,7 +335,7 @@ class Stack:
         """
         This document is a detailed reference to Contentstack’s Image Delivery
         API and covers the parameters that you can add to the URL to retrieve,
-        manipulate (or convert) image files and display it to your web or 
+        manipulate (or convert) image files and display it to your web or
         mobile properties.\n
 
         :param image_url: base url on which queries to apply
